#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

inputDimension = 3

myFunction = TranslationFunction([2.0, 3.0, -4.0])
myFunction.setName("translationFunction")
inPoint = Point(inputDimension)
inPoint[0] = 7.0
inPoint[1] = 8.0
inPoint[2] = 9.0
outPoint = myFunction(inPoint)
print("myFunction=", repr(myFunction))
print(myFunction.getName(), "( ", repr(inPoint), " ) = ", repr(outPoint))
print(myFunction.getName(), ".gradient( ", repr(inPoint), " ) = ",
      repr(myFunction.gradient(inPoint)))
print(myFunction.getName(), ".hessian( ", repr(inPoint), " ) = ",
      repr(myFunction.hessian(inPoint)))




import openturns.shims as ot
import openturns.testing as ott

assert ot.Arcsine() is not None

print(ot.Beta(2.0, 4.0, 0.0, 1.0))
ott.assert_almost_equal(
    ot.Beta(2.0, 4.0, 0.0, 1.0).getParameter(), [2.0, 2.0, 0.0, 1.0])

print(ot.Frechet(6.0, 1.5))
ott.assert_almost_equal(ot.Frechet(6.0, 1.5).getParameter(), [1.5, 6.0, 0.0])

print(ot.Gumbel(558.0, 1013.0))
ott.assert_almost_equal(
    ot.Gumbel(558.0, 1013.0).getStandardDeviation(), [0.00229848])

print(ot.InverseGamma(2.0, 3.0))
ott.assert_almost_equal(ot.InverseGamma(2.0, 3.0).getParameter(), [3.0, 2.0])

print(ot.InverseNormal(2.0, 3.0))
ott.assert_almost_equal(ot.InverseNormal(2.0, 3.0).getParameter(), [3.0, 2.0])

print(ot.Laplace(2.0, 3.0))
ott.assert_almost_equal(ot.Laplace(2.0, 3.0).getParameter(), [3.0, 2.0])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

ot.PlatformInfo.SetNumericalPrecision(6)

dim = 2
p1 = ot.Point(dim, -1.0)
p2 = ot.Point(dim, 2.0)
domain = ot.Interval(p1, p2)

complement = ot.DomainComplement(domain)

# Inside
p3 = (p1 + p2) * 0.5
# Outside
p4 = 2.0 * p2
print("Domain=", domain)
print("Complement=", complement)
# Accessors
print("Dimension=", complement.getDimension())
# Contains
print("is point ", p3, " inside complement? ",  complement.contains(p3))
print("is point ", p4, " inside complement? ",  complement.contains(p4))
sample = [p3, p4]
print("is sample ", sample, " inside? ",  complement.contains(sample))



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)


all_cases = [GeneralizedExtremeValue(2.0, 1.5, -0.15),
             GeneralizedExtremeValue(2.0, 1.5,  0.0),
             GeneralizedExtremeValue(2.0, 1.5,  0.15)]
for i in range(len(all_cases)):
    distribution = all_cases[i]
    print("#" * 50)
    print("Distribution ", distribution)

    for dist in ['WeibullMax', 'Frechet', 'Gumbel']:
        try:
            eval("print('conversion as ', distribution.as" + dist + "())")
        except:
            pass

    # Is this distribution elliptical ?
    print("Elliptical = ", distribution.isElliptical())

    # Is this distribution continuous ?
    print("Continuous = ", distribution.isContinuous())

    # Test for realization of distribution
    oneRealization = distribution.getRealization()
    print("oneRealization=", oneRealization)

    # Test for sampling
    size = 10000
    oneSample = distribution.getSample(size)
    print("oneSample first=", oneSample[0], " last=", oneSample[size - 1])
    print("mean=", oneSample.computeMean())
    print("covariance=", oneSample.computeCovariance())
    size = 100
    for i in range(2):
        print(
            "Kolmogorov test for the generator, sample size=", size, " is ",
            FittingTest.Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure())
        size *= size

    # Define a point
    point = [1.0] * distribution.getDimension()
    print("Point= ", point)

    # Show PDF and CDF of point
    eps = 1e-5
    DDF = distribution.computeDDF(point)
    print("ddf     =", DDF)
    print(
        "ddf (FD)=", Point(1, (distribution.computePDF(point[0] + eps) - distribution.computePDF(point[0] - eps)) / (2.0 * eps)))
    LPDF = distribution.computeLogPDF(point)
    print("log pdf=", Point(1, LPDF))
    PDF = distribution.computePDF(point)
    print("pdf     =", Point(1, PDF))
    print(
        "pdf (FD)=", Point(1, (distribution.computeCDF(point[0] + eps) - distribution.computeCDF(point[0] - eps)) / (2.0 * eps)))
    CDF = distribution.computeCDF(point)
    print("cdf=", Point(1, CDF))
    CCDF = distribution.computeComplementaryCDF(point)
    print("ccdf=", Point(1, CCDF))
    Survival = distribution.computeSurvivalFunction(point)
    print("survival=", Point(1, Survival))
    InverseSurvival = distribution.computeInverseSurvivalFunction(0.95)
    print("Inverse survival=", InverseSurvival)
    print("Survival(inverse survival)=",
          Point(1, distribution.computeSurvivalFunction(InverseSurvival)))
    PDFgr = distribution.computePDFGradient(point)
    print("pdf gradient     =", PDFgr)
    PDFgrFD = Point(3)
    PDFgrFD[0] = (GeneralizedExtremeValue(distribution.getMu() + eps, distribution.getSigma(), distribution.getXi()).computePDF(point) -
                  GeneralizedExtremeValue(distribution.getMu() - eps, distribution.getSigma(), distribution.getXi()).computePDF(point)) / (2.0 * eps)
    PDFgrFD[1] = (GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma() + eps, distribution.getXi()).computePDF(point) -
                  GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma() - eps, distribution.getXi()).computePDF(point)) / (2.0 * eps)
    PDFgrFD[2] = (GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma(), distribution.getXi() + eps).computePDF(point) -
                  GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma(), distribution.getXi() - eps).computePDF(point)) / (2.0 * eps)
    print("pdf gradient (FD)=", PDFgrFD)
    CDFgr = distribution.computeCDFGradient(point)
    print("cdf gradient     =", CDFgr)
    CDFgrFD = Point(3)
    CDFgrFD[0] = (GeneralizedExtremeValue(distribution.getMu() + eps, distribution.getSigma(), distribution.getXi()).computeCDF(point) -
                  GeneralizedExtremeValue(distribution.getMu() - eps, distribution.getSigma(), distribution.getXi()).computeCDF(point)) / (2.0 * eps)
    CDFgrFD[1] = (GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma() + eps, distribution.getXi()).computeCDF(point) -
                  GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma() - eps, distribution.getXi()).computeCDF(point)) / (2.0 * eps)
    CDFgrFD[2] = (GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma(), distribution.getXi() + eps).computeCDF(point) -
                  GeneralizedExtremeValue(distribution.getMu(), distribution.getSigma(), distribution.getXi() - eps).computeCDF(point)) / (2.0 * eps)
    print("cdf gradient (FD)=", CDFgrFD)
    quantile = distribution.computeQuantile(0.95)
    print("quantile=", quantile)
    print("cdf(quantile)=", distribution.computeCDF(quantile))
    print("entropy=%.6f" % distribution.computeEntropy())
    # Confidence regions
    prob, threshold = distribution.computeMinimumVolumeIntervalWithMarginalProbability(
        0.95)
    print("Minimum volume interval=", prob)
    print("threshold=", threshold)
    levelSet, beta = distribution.computeMinimumVolumeLevelSetWithThreshold(
        0.95)
    print("Minimum volume level set=", levelSet)
    print("beta=", Point(1, beta))
    interval, beta = distribution.computeBilateralConfidenceIntervalWithMarginalProbability(
        0.95)
    print("Bilateral confidence interval=", interval)
    print("beta=", Point(1, beta))
    interval, beta = distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(
        0.95, False)
    print("Unilateral confidence interval (lower tail)=", interval)
    print("beta=", Point(1, beta))
    interval, beta = distribution.computeUnilateralConfidenceIntervalWithMarginalProbability(
        0.95, True)
    print("Unilateral confidence interval (upper tail)=", interval)
    print("beta=", Point(1, beta))
    mean = distribution.getMean()
    print("mean=", mean)
    standardDeviation = distribution.getStandardDeviation()
    print("standard deviation=", standardDeviation)
    skewness = distribution.getSkewness()
    print("skewness=", skewness)
    kurtosis = distribution.getKurtosis()
    print("kurtosis=", kurtosis)
    covariance = distribution.getCovariance()
    print("covariance=", covariance)
    correlation = distribution.getCorrelation()
    print("correlation=", correlation)
    spearman = distribution.getSpearmanCorrelation()
    print("spearman=", spearman)
    kendall = distribution.getKendallTau()
    print("kendall=", kendall)
    parameters = distribution.getParametersCollection()
    print("parameters=", parameters)
    for i in range(6):
        print("standard moment n=", i, ", value=",
              distribution.getStandardMoment(i))
    print("Standard representative=",
          distribution.getStandardRepresentative())
    print("mu=", distribution.getMu())
    print("sigma=", distribution.getSigma())
    print("xi=", distribution.getXi())
    print("Actual distribution=", distribution.getActualDistribution())
    distribution.setActualDistribution(
        distribution.getActualDistribution())
    print("Distribution from actual distribution=", distribution)



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot
import openturns.testing as ott
import math as m
import sys

ot.TESTPREAMBLE()
ot.PlatformInfo.SetNumericalPrecision(3)

m = 10
x = [[0.5 + i] for i in range(m)]

#ot.ResourceMap.SetAsUnsignedInteger( "OptimizationAlgorithm-DefaultMaximumEvaluationNumber", 100)
inVars = ["a", "b", "c", "x"]
formulas = ["a + b * exp(c * x)", "(a * x^2 + b) / (c + x^2)"]
model = ot.SymbolicFunction(inVars, formulas)
p_ref = [2.8, 1.2, 0.5]
params = [0, 1, 2]
modelX = ot.ParametricFunction(model, params, p_ref)
y = modelX(x)
y += ot.Normal([0.0]*2, [0.05]*2, ot.IdentityMatrix(2)).getSample(m)
candidate = [1.0]*3
bootstrapSizes = [0, 100]
for bootstrapSize in bootstrapSizes:
    algo = ot.NonLinearLeastSquaresCalibration(modelX, x, y, candidate)
    algo.setBootstrapSize(bootstrapSize)
    algo.run()
    # To avoid discrepance between the plaforms with or without CMinpack
    print("result (Auto)=", algo.getResult().getParameterMAP())
    algo.setOptimizationAlgorithm(ot.MultiStart(ot.TNC(), ot.LowDiscrepancyExperiment(ot.SobolSequence(), ot.Normal(candidate, ot.CovarianceMatrix(
        ot.Point(candidate).getDimension())), ot.ResourceMap.GetAsUnsignedInteger("NonLinearLeastSquaresCalibration-MultiStartSize")).generate()))
    algo.run()
    # To avoid discrepance between the plaforms with or without CMinpack
    print("result  (TNC)=", algo.getResult().getParameterMAP())



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

# Create an intance
myFunc = ot.FieldFunction()

print('myFunc=', myFunc)
# Get the input and output description
print('myFunc input description=', myFunc.getInputDescription())
print('myFunc output description=', myFunc.getOutputDescription())
# Get the input and output dimension, based on description
print('myFunc input dimension=', myFunc.getInputDimension())
print('myFunc output dimension=', myFunc.getOutputDimension())
print('myFunc input dimension=', myFunc.getInputMesh().getDimension())
# Get the number of calls
print('called ', myFunc.getCallsNumber(), ' times')



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

try:
    jacobi = JacobiFactory(2.5, 3.5, JacobiFactory.PROBABILITY)
    print("jacobi=", jacobi)
    jacobi = JacobiFactory(2.5, 3.5, JacobiFactory.ANALYSIS)
    print("jacobi=", jacobi)
    jacobi = JacobiFactory(2.5, 3.5)
    print("jacobi=", jacobi)
    for i in range(10):
        print("jacobi(", i, ")=", jacobi.build(i))
    roots = jacobi.getRoots(10)
    print("jacobi(10) roots=", repr(roots))
    nodes, weights = jacobi.getNodesAndWeights(10)
    print("jacobi(10) nodes=", nodes, "and weights=", weights)
except:
    import sys
    print("t_JacobiFactory_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

nu = 4.5
dim = 5
distribution = ot.Student(nu, dim)
transformation = InverseRosenblattEvaluation(distribution)
print("transformation=", repr(transformation))
point = Point(dim, 0.75)
print("transformation(", point, ")=", repr(transformation(point)))
print("transformation parameters gradient=", repr(
    transformation.parameterGradient(point)))
print("input dimension=", transformation.getInputDimension())
print("output dimension=", transformation.getOutputDimension())



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

ot.TESTPREAMBLE()

try:
    distribution = ot.Burr(2.5, 1.5)
    size = 10000
    sample = distribution.getSample(size)
    factory = ot.BurrFactory()
    estimatedDistribution = factory.build(sample)
    print("distribution=", repr(distribution))
    print("Estimated distribution=", repr(estimatedDistribution))
    estimatedDistribution = factory.build()
    print("Default distribution=", estimatedDistribution)
    estimatedDistribution = factory.build(
        distribution.getParameter())
    print("Distribution from parameters=", estimatedDistribution)
    estimatedBurr = factory.buildAsBurr(sample)
    print("Burr          =", distribution)
    print("Estimated burr=", estimatedBurr)
    estimatedBurr = factory.buildAsBurr()
    print("Default burr=", estimatedBurr)
    estimatedBurr = factory.buildAsBurr(distribution.getParameter())
    print("Burr from parameters=", estimatedBurr)

    try:
        estimatedBurr = factory.build(ot.Normal(1e-3, 1e-5).getSample(100))
        print('Estimated burr=', estimatedBurr)
    except:
        pass

    ot.RandomGenerator.SetSeed(0)
    try:
        estimatedBurr = factory.build(ot.UserDefined(
            ot.LogNormal(7.71, 1.0056).getSample(500)).getSupport())
        #print('Estimated burr=', estimatedBurr)
    except:
        pass

except:
    import sys
    print("t_BurrFactory_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    left = Uniform(-1.0, 2.0)
    right = Normal(1.0, 2.0)
    distribution = ProductDistribution(left, right)
    print("Distribution ", distribution)

    # Is this distribution elliptical ?
    print("Elliptical =", distribution.isElliptical())

    # Is this distribution continuous ?
    print("Continuous =", distribution.isContinuous())

    # Test for realization of distribution
    oneRealization = distribution.getRealization()
    print("oneRealization=", oneRealization)

    # Test for sampling
    size = 10000
    oneSample = distribution.getSample(size)
    print("oneSample first=", oneSample[0], " last=", oneSample[size - 1])
    print("mean=", oneSample.computeMean())
    print("covariance=", oneSample.computeCovariance())

    # Define a point
    point = [2.5]*distribution.getDimension()
    print("Point= ", point)

    # Show PDF and CDF of point
    DDF = distribution.computeDDF(point)
    print("ddf      =", DDF)
    PDF = distribution.computePDF(point)
    print("pdf      =%.6g" % PDF)
    CDF = distribution.computeCDF(point)
    print("cdf      =%.6g" % CDF)
    PDFgr = distribution.computePDFGradient(point)
    print("pdf gradient      =", PDFgr)
    CDFgr = distribution.computeCDFGradient(point)
    print("cdf gradient      =", CDFgr)
    quantile = distribution.computeQuantile(0.95)
    print("quantile     =", quantile)
    print("cdf(quantile)=%.6g" % distribution.computeCDF(quantile))
    print("entropy=%.6g" % distribution.computeEntropy())
    print("entropy (MC)=%.6g" % -
          distribution.computeLogPDF(distribution.getSample(10000)).computeMean()[0])
    mean = distribution.getMean()
    print("mean      =", mean)
    standardDeviation = distribution.getStandardDeviation()
    print("standard deviation      =", standardDeviation)
    skewness = distribution.getSkewness()
    print("skewness      =", skewness)
    kurtosis = distribution.getKurtosis()
    print("kurtosis      =", kurtosis)
    covariance = distribution.getCovariance()
    print("covariance      =", covariance)
    parameters = distribution.getParametersCollection()
    print("parameters      =", parameters)
    for i in range(6):
        print("standard moment n=", i, ", value=",
              distribution.getStandardMoment(i))
    print("Standard representative=", distribution.getStandardRepresentative())

    # Specific to this distribution
    print("left=", distribution.getLeft())
    print("right=", distribution.getRight())

    # For ticket 957
    distribution = Uniform() * Uniform() * Uniform()
    print("distribution=", distribution)
    print("mean=", distribution.getMean())
    print("standard deviation=", distribution.getStandardDeviation())
except:
    import sys
    print("t_ProductDistribution_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:
    PlatformInfo.SetNumericalPrecision(5)
    mean = Point(3)
    mean[0] = 1.0
    mean[1] = 2.0
    mean[2] = 3.0
    sigma = Point(3)
    sigma[0] = 2.0
    sigma[1] = 3.0
    sigma[2] = 4.0

    # Create a collection of distribution attente TUI
    aCollection = []
    try:
        aCollection[10] = Normal()
    except:
        pass
    # Create a marginal : distribution 1D
    marginal = Normal(mean[0], sigma[0])
    marginal.setName("First")
    component = Description(1)
    component[0] = "One"
    marginal.setDescription(component)
    # Fill the first marginal of aCollection
    aCollection.append(Distribution(marginal))
    aCollection[0].setName("First")
    # Create a second marginal : distribution 1D
    marginal = Normal(mean[1], sigma[1])
    marginal.setName("Second")
    component[0] = "Two"
    marginal.setDescription(component)
    # Fill the second marginal of aCollection
    aCollection.append(Distribution(marginal))
    aCollection[1].setName("Second")
    # Create a third marginal : distribution 1D
    marginal = Normal(mean[2], sigma[2])
    marginal.setName("Third")
    component[0] = "Three"
    marginal.setDescription(component)
    # Fill the third marginal of aCollection
    aCollection.append(Distribution(marginal))
    aCollection[2].setName("Third")
    # Create a copula : IndependentCopula
    dim = len(aCollection)
    aCopula = IndependentCopula(dim)
    aCopula.setName("Independent copula")
    print("Copula = ", repr(aCopula))
    print("Copula = ", aCopula)
    # Instanciate one distribution object
    distribution = ComposedDistribution(aCollection, aCopula)
    distribution.setName("myDist")
    print("Distribution = ", repr(distribution))
    print("Distribution = ", distribution)
    print("Parameters = ", repr(distribution.getParametersCollection()))
    print("Mean = ", repr(distribution.getMean()))
    print("Covariance = ", repr(distribution.getCovariance()))
    # Is this distribution elliptical ?
    print("Elliptical = ", distribution.isElliptical())
    # Has this distribution an elliptical copula?
    print("Elliptical copula = ", distribution.hasEllipticalCopula())

    # Has this distribution an independent copula?
    print("Independent copula = ",  distribution.hasIndependentCopula())

    # Test for realization of distribution
    oneRealization = distribution.getRealization()
    print("oneRealization=", repr(oneRealization))

    # Test for sampling
    size = 10
    oneSample = distribution.getSample(size)
    print("oneSample=", repr(oneSample))

    # Test for sampling
    size = 10000
    anotherSample = distribution.getSample(size)
    print("anotherSample mean=", repr(anotherSample.computeMean()))
    print("anotherSample covariance=", repr(anotherSample.computeCovariance()))

    # Define a point
    zero = Point(dim, 0.0)

    # Show PDF and CDF of zero point
    zeroPDF = distribution.computePDF(zero)
    zeroCDF = distribution.computeCDF(zero)
    print("Zero point= ", repr(zero), " pdf=%.6f" %
          zeroPDF, " cdf=%.6f" % zeroCDF)

    # Get 95% quantile
    quantile = Point(distribution.computeQuantile(0.95))
    print("Quantile=", repr(quantile))
    print("CDF(quantile)=%.6f" % distribution.computeCDF(quantile))

    # Get 5% quantile
    quantile = Point(distribution.computeQuantile(0.95, True))
    print("Quantile=", repr(quantile))

    # Get 95% survival function
    inverseSurvival = Point(distribution.computeInverseSurvivalFunction(0.95))
    print("InverseSurvival=", repr(inverseSurvival))
    print("Survival(inverseSurvival)=%.6f" %
          distribution.computeSurvivalFunction(inverseSurvival))
    print("entropy=%.6f" % distribution.computeEntropy())
    # Confidence regions
    if distribution.getDimension() <= 2:
        threshold = Point()
        print("Minimum volume interval=",
              distribution.computeMinimumVolumeInterval(0.95, threshold))
        print("threshold=", threshold)
        beta = Point()
        levelSet = distribution.computeMinimumVolumeLevelSet(0.95, beta)
        print("Minimum volume level set=", levelSet)
        print("beta=", beta)
        print("Bilateral confidence interval=",
              distribution.computeBilateralConfidenceInterval(0.95, beta))
        print("beta=", beta)
        print("Unilateral confidence interval (lower tail)=",
              distribution.computeUnilateralConfidenceInterval(0.95, False, beta))
        print("beta=", beta)
        print("Unilateral confidence interval (upper tail)=",
              distribution.computeUnilateralConfidenceInterval(0.95, True, beta))
        print("beta=", beta)

    # Reference : Normal nD, correlation matrix = identity
    ref = Normal(mean, sigma,  CorrelationMatrix(dim))
    print("Reference=")
    print("Zero point= ", repr(zero), " pdf= %.6f" % ref.computePDF(zero), " cdf= %.6f" %
          ref.computeCDF(zero), " quantile= ", repr(ref.computeQuantile(0.95)))

    # Extract the marginals
    for i in range(dim):
        margin = distribution.getMarginal(i)
        print("margin=", repr(margin))
        print("margin PDF=%.6f" % margin.computePDF(Point(1)))
        print("margin CDF=%.6f" % margin.computeCDF(Point(1)))
        print("margin quantile=", repr(margin.computeQuantile(0.5)))
        print("margin realization=", repr(margin.getRealization()))

    # Extract a 2-D marginal
    indices = Indices(2, 0)
    indices[0] = 1
    indices[1] = 0
    print("indices=", repr(indices))
    margins = distribution.getMarginal(indices)
    print("margins=", repr(margins))
    print("margins PDF=%.6f" % margins.computePDF(Point(2)))
    print("margins CDF=%.6f" % margins.computeCDF(Point(2)))
    quantile = Point(margins.computeQuantile(0.5))
    print("margins quantile=", repr(quantile))
    print("margins CDF(qantile)=%.6f" % margins.computeCDF(quantile))
    print("margins realization=", repr(margins.getRealization()))
    x = 0.6
    y = [0.2]
    print("conditional PDF=%.6f" % distribution.computeConditionalPDF(x, y))
    print("conditional CDF=%.6f" % distribution.computeConditionalCDF(x, y))
    print("conditional quantile=%.6f" %
          distribution.computeConditionalQuantile(x, y))
    point = [0.6]*dim
    print("sequential conditional PDF=",
          distribution.computeSequentialConditionalPDF(point))
    print("sequential conditional CDF=",
          distribution.computeSequentialConditionalCDF(point))
    print("sequential conditional quantile=",
          distribution.computeSequentialConditionalQuantile(point))

#

    # With a Normal copula
    correlation = CorrelationMatrix(dim)
    for i in range(1, dim):
        correlation[i - 1, i] = 0.25
    anotherCopula = NormalCopula(correlation)
    anotherCopula.setName("Normal copula")

    # Instanciate one distribution object
    distribution = ComposedDistribution(aCollection, anotherCopula)
    distribution.setName("myDist")
    distributionRef = Normal(mean, sigma, correlation)
    print("Distribution ", repr(distribution))
    print("Parameters ", repr(distribution.getParametersCollection()))

    # Show PDF and CDF at point
    point = Point(dim, 0.0)
    print("PDF      =%.6f" % distribution.computePDF(point))
    print("PDF (ref)=%.6f" % distributionRef.computePDF(point))
    print("CDF      =%.6f" % distribution.computeCDF(point))
    print("CDF (ref)=%.6f" % distributionRef.computeCDF(point))
    print("Survival      =%.6f" % distribution.computeSurvivalFunction(point))
    print("Survival (ref)=%.6f" %
          distributionRef.computeSurvivalFunction(point))
    # 95% quantile
    quantile = distribution.computeQuantile(0.95)
    print("Quantile      =", repr(quantile))
    print("Quantile (ref)=", repr(distributionRef.computeQuantile(0.95)))
    print("CDF(quantile)=%.6f" % distribution.computeCDF(quantile))
    print("Mean      =", repr(distribution.getMean()))
    print("Mean (ref)=", repr(distributionRef.getMean()))
    print("Standard deviation      =", repr(
        distribution.getStandardDeviation()))
    print("Standard deviation (ref)=", repr(
        distributionRef.getStandardDeviation()))
    print("Skewness      =", repr(distribution.getSkewness()))
    print("Skewness (ref)=", repr(distributionRef.getSkewness()))
    print("Kurtosis      =", repr(distribution.getKurtosis()))
    print("Kurtosis (ref)=", repr(distributionRef.getKurtosis()))
    print("Covariance      =", repr(distribution.getCovariance()))
    print("Covariance (ref)=", repr(distributionRef.getCovariance()))
    anotherSample = distribution.getSample(size)
    print("anotherSample mean=", repr(anotherSample.computeMean()))
    print("anotherSample covariance=", repr(anotherSample.computeCovariance()))

    # test transfo
    sample = distribution.getSample(10)
    print(sample)
    sample_iso = distribution.getIsoProbabilisticTransformation()(sample)
    print(sample_iso)
    sample_inv = distribution.getInverseIsoProbabilisticTransformation()(
        sample_iso)
    print(sample_inv)
    x = 0.6
    y = [0.2]*(dim-1)
    print("conditional PDF=%.6f" % distribution.computeConditionalPDF(x, y))
    print("conditional CDF=%.6f" % distribution.computeConditionalCDF(x, y))
    print("conditional quantile=%.6f" %
          distribution.computeConditionalQuantile(x, y))
    pt = Point([i + 1.5 for i in range(dim)])
    print("sequential conditional PDF=",
          distribution.computeSequentialConditionalPDF(point))
    resCDF = distribution.computeSequentialConditionalCDF(pt)
    print("sequential conditional CDF(", pt, ")=", resCDF)
    print("sequential conditional quantile(", resCDF, ")=",
          distribution.computeSequentialConditionalQuantile(resCDF))

except:
    import sys
    print("t_ComposedDistribution_std.py",
          sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

from math import *
from math import *


def printPoint(point, digits):
    oss = "["
    eps = pow(0.1, digits)
    for i in range(point.getDimension()):
        if i == 0:
            sep = ""
        else:
            sep = ","
        if fabs(point[i]) < eps:
            oss += sep + '%.6f' % fabs(point[i])
        else:
            oss += sep + '%.6f' % point[i]
        sep = ","
    oss += "]"
    return oss


TESTPREAMBLE()

try:

        # We create a numerical math function
        # Analytical construction
    inputFunc = Description(2)
    inputFunc[0] = "x0"
    inputFunc[1] = "x1"
    formulas = Description(1)
    formulas[0] = "-(6+x0^2-x1)"
    print("formulas=", formulas)
    myFunction = SymbolicFunction(inputFunc, formulas)

    dim = myFunction.getInputDimension()
    # We create a normal distribution point of dimension 1
    mean = Point(dim, 0.0)
# x0
    mean[0] = 5.0
# x1
    mean[1] = 2.1
    sigma = Point(dim, 0.0)
# x0
    sigma[0] = 3.3
# x1
    sigma[1] = 3.0
    R = IdentityMatrix(dim)

#
    testDistributions = DistributionCollection(2)
    testDistributions[0] = Normal(mean, sigma, R)
    marginals = DistributionCollection(2)
    marginals[0] = testDistributions[0].getMarginal(0)
    marginals[1] = testDistributions[0].getMarginal(1)
    testDistributions[1] = ComposedDistribution(marginals, NormalCopula(R))
    for i in range(1):

        myDistribution = testDistributions[i]
        # We name the components of the distribution
        componentDescription = Description(dim)
        componentDescription[0] = "Marginal 1"
        componentDescription[1] = "Marginal 2"
        myDistribution.setDescription(componentDescription)

        # We create a 'usual' RandomVector from the Distribution
        vect = RandomVector(myDistribution)

        # We create a composite random vector
        output = CompositeRandomVector(myFunction, vect)
        outputDescription = Description(1)
        outputDescription[0] = "Interest Variable 1"
        output.setDescription(outputDescription)

        # We create an Event from this RandomVector
        myEvent = ThresholdEvent(output, Greater(), 0.0)

        # We create a NearestPoint algorithm
        myCobyla = Cobyla()
        myCobyla.setMaximumEvaluationNumber(200)
        myCobyla.setMaximumAbsoluteError(1.0e-10)
        myCobyla.setMaximumRelativeError(1.0e-10)
        myCobyla.setMaximumResidualError(1.0e-10)
        myCobyla.setMaximumConstraintError(1.0e-10)
        print("myCobyla=", myCobyla)

        # We create a FORM algorithm
        # The first parameter is an OptimizationAlgorithm
        # The second parameter is an event
        # The third parameter is a starting point for the design point research
        myAlgo = FORM(myCobyla, myEvent, mean)

        print("FORM=", myAlgo)

        # Perform the simulation
        myAlgo.run()

        # Stream out the result
        result = FORMResult(myAlgo.getResult())
        digits = 5
        print("importance factors=", printPoint(
            result.getImportanceFactors(), digits))
        print("Hasofer reliability index=%.6f" %
              result.getHasoferReliabilityIndex())
        print("result=", result)

        # Hasofer Reliability Index Sensitivity
        hasoferReliabilityIndexSensitivity = result.getHasoferReliabilityIndexSensitivity(
        )
        print("hasoferReliabilityIndexSensitivity = ",
              repr(hasoferReliabilityIndexSensitivity))

        # Event Probability Sensitivity
        eventProbabilitySensitivity = result.getEventProbabilitySensitivity()
        print("eventProbabilitySensitivity = ",
              repr(eventProbabilitySensitivity))

except:
    import sys
    print("t_FORM_sensitivity.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

# Default constructor
flat1 = ot.IndicesCollection()
print('flat1=', flat1)

# Constructor with Collection<Indices>
coll2 = []
ind1 = ot.Indices(1)
ind4 = ot.Indices(4)
ind4.fill(8)
ind3 = ot.Indices(3)
ind3.fill(3)
coll2.append(ind1)
coll2.append(ind4)
coll2.append(ind3)
flat2 = ot.IndicesCollection(coll2)
print('flat2=', flat2)

# Copy constructor
flat3 = ot.IndicesCollection(flat2)
print('flat3=', flat3)

# Strided
coll4 = []
coll4.append(ind4)
coll4.append(ind4)
coll4.append(ind4)
strided1 = ot.IndicesCollection(coll4)
print('strided1=', strided1)

# Constructor with dimensions and values
full = ot.Indices(16)
full.fill()
strided2 = ot.IndicesCollection(8, 2, full)
print('strided2=', strided2)

# slicing
print('strided2[2] = ', strided2[2])
strided2[2] = [1, 3]
print('strided2 = ', strided2)
try:
    strided2[2] = [1, 2, 3]
    print('Should throw')
except TypeError:
    pass

# loop
for x in strided2:
    print(x)

try:
    ot.IndicesCollection([['zou']])
except:
    print('ok')



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot

size = 100

# ARMA parameters
arcoefficients = ot.ARMACoefficients([0.3])
macoefficients = ot.ARMACoefficients(0)
timeGrid = ot.RegularGrid(0.0, 0.1, size)

# White noise ==> gaussian
whiteNoise = ot.WhiteNoise(ot.Normal(), timeGrid)
myARMA = ot.ARMA(arcoefficients, macoefficients, whiteNoise)

# A realization of the ARMA process
# The realization is supposed to be of a stationnary process
realization = ot.TimeSeries(myARMA.getRealization())

# In the strategy of tests, one has to detect a trend tendency
# We check if the time series writes as x_t = a +b * t + c * x_{t-1}
# H0 = c is equal to one and thus
# p-value threshold : probability of the H0 reject zone : 0.05
# p-value : probability (test variable decision > test variable decision (statistic) evaluated on data)
# Test = True <=> p-value > p-value threshold
test = ot.DickeyFullerTest(realization)
print("Drift and linear trend model=",
      test.testUnitRootInDriftAndLinearTrendModel(0.05))
print("Drift model=", test.testUnitRootInDriftModel(0.05))
print("AR1 model=", test.testUnitRootInAR1Model(0.05))



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:

    # Hanning filter
    myHanningFilter = Hanning()
    print("myHanningFilter = ", myHanningFilter)

    # Hamming filter
    myHammingFilter = Hamming()
    print("myHammingFilter = ",  myHammingFilter)

    # Evaluation of values between t=0 and t=1 using a step = 0.01
    steps = 100
    tMin = 0.0
    tMax = 1.0
    tStep = (tMax - tMin) / steps

    for i in range(steps + 1):
        t = tMin + i * tStep
        print('t = %g Hanning = %g Hamming = %g' %
              (t, myHanningFilter(t), myHammingFilter(t)))


except:
    import sys
    print("t_FilteringWindows_std.py", sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
import openturns as ot
import openturns.testing as ott
import math as m
import sys

ot.TESTPREAMBLE()
ot.PlatformInfo.SetNumericalPrecision(3)

m = 10
x = [[0.5 + i] for i in range(m)]

inVars = ["a", "b", "c", "x"]
formulas = ["a + b * exp(c * x)", "(a * x^2 + b) / (c + x^2)"]
model = ot.SymbolicFunction(inVars, formulas)
p_ref = [2.8, 1.2, 0.5]
params = [0, 1, 2]
modelX = ot.ParametricFunction(model, params, p_ref)
y = modelX(x)
y += ot.Normal([0.0]*2, [0.05]*2, ot.IdentityMatrix(2)).getSample(m)
candidate = [1.0]*3
priorCovariance = ot.CovarianceMatrix(3)
for i in range(3):
    priorCovariance[i, i] = 3.0 + (1.0 + i) * (1.0 + i)
    for j in range(i):
        priorCovariance[i, j] = 1.0 / (1.0 + i + j)
errorCovariance = ot.CovarianceMatrix(2)
for i in range(2):
    errorCovariance[i, i] = 2.0 + (1.0 + i) * (1.0 + i)
    for j in range(i):
        errorCovariance[i, j] = 1.0 / (1.0 + i + j)
globalErrorCovariance = ot.CovarianceMatrix(2 * m)
for i in range(2 * m):
    globalErrorCovariance[i, i] = 2.0 + (1.0 + i) * (1.0 + i)
    for j in range(i):
        globalErrorCovariance[i, j] = 1.0 / (1.0 + i + j)
bootstrapSizes = [0, 100]
for bootstrapSize in bootstrapSizes:
    algo = ot.GaussianNonLinearCalibration(
        modelX, x, y, candidate, priorCovariance, errorCovariance)
    algo.setBootstrapSize(bootstrapSize)
    algo.run()
    # To avoid discrepance between the plaforms with or without CMinpack
    print("result   (Auto)=", algo.getResult().getParameterMAP())
    algo.setOptimizationAlgorithm(ot.MultiStart(ot.TNC(), ot.LowDiscrepancyExperiment(ot.SobolSequence(), ot.Normal(candidate, ot.CovarianceMatrix(
        ot.Point(candidate).getDimension())), ot.ResourceMap.GetAsUnsignedInteger("GaussianNonLinearCalibration-MultiStartSize")).generate()))
    algo.run()
    # To avoid discrepance between the plaforms with or without CMinpack
    print("result    (TNC)=", algo.getResult().getParameterMAP())
    algo = ot.GaussianNonLinearCalibration(
        modelX, x, y, candidate, priorCovariance, globalErrorCovariance)
    algo.setBootstrapSize(bootstrapSize)
    algo.run()
    print("result (Global)=", algo.getResult().getParameterMAP())



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()

try:

    inputDimension = 3
    outputDimension = 2

    # Constant term
    constant = SymmetricTensor(inputDimension, outputDimension)
    constant[0, 0, 0] = 7.0
    constant[0, 0, 1] = -7.0
    constant[0, 1, 0] = 8.0
    constant[0, 1, 1] = -8.0
    constant[0, 2, 0] = 9.0
    constant[0, 2, 1] = -9.0
    constant[1, 0, 0] = 8.0
    constant[1, 0, 1] = -8.0
    constant[1, 1, 0] = 10.0
    constant[1, 1, 1] = -10.0
    constant[1, 2, 0] = 11.0
    constant[1, 2, 1] = -11.0
    constant[2, 0, 0] = 9.0
    constant[2, 0, 1] = -9.0
    constant[2, 1, 0] = 11.0
    constant[2, 1, 1] = -11.0
    constant[2, 2, 0] = 12.0
    constant[2, 2, 1] = -12.0

    myHessian = ConstantHessian(constant)
    myHessian.setName("constantHessian")
    inPoint = Point(inputDimension)
    inPoint[0] = 7.0
    inPoint[1] = 8.0
    inPoint[2] = 9.0
    outTensor = myHessian.hessian(inPoint)
    print("myHessian=", repr(myHessian))
    print(myHessian.getName(), "( ", repr(inPoint), " ) = ", repr(outTensor))

except:
    import sys
    print("t_ConstantHessian_std.py",
          sys.exc_info()[0], sys.exc_info()[1])



#! /usr/bin/env python

from __future__ import print_function
from openturns import *

TESTPREAMBLE()
RandomGenerator.SetSeed(0)

try:

    # We create a numerical math function */
    myFunction = SymbolicFunction(
        ["E", "F", "L", "I"], ["-F*L^3/(3*E*I)"])

    dim = myFunction.getInputDimension()

    # We create a normal distribution point of dimension dim
    myDistribution = Normal(dim)

    # We create a 'usual' RandomVector from the Distribution
    vect = RandomVector(myDistribution)

    # We create a composite random vector
    output = CompositeRandomVector(myFunction, vect)

    # We create an StandardEvent from this RandomVector
    myStandardEvent = StandardEvent(output, Less(), 1.0)
    print("myStandardEvent=", myStandardEvent)

    # We compute one realization of the event
    # E = (Y=f(X), operator, threshold)
    # E as a RandomVector : Y
    print("myStandardEvent (as a RandomVector) realization =",
          repr(RandomVector.getRealization(myStandardEvent)))

    # E as a Bernoulli
    print("myStandardEvent realization=", repr(
        myStandardEvent.getRealization()))

    # We compute a sample of the event
    print("myStandardEvent sample=", repr(myStandardEvent.getSample(10)))

    # Build a standard event based on an event

    R = CorrelationMatrix(dim)
    for i in range(dim - 1):
        R[i + 1, i] = 0.5

    mean = Point(dim, 0.0)
    sigma = Point(dim, 1.0)
    myDistribution2 = Normal(mean, sigma, R)

    # We create a 'usual' RandomVector from the Distribution
    vect2 = RandomVector(myDistribution2)

    # We create a composite random vector
    output2 = CompositeRandomVector(myFunction, vect2)

    # We create an Event from this RandomVector */
    myEvent = ThresholdEvent(output2, Less(), 1.0)

    # Create a StandardEvent based on this Event */
    stdEvent = StandardEvent(myEvent)

    # Check if the StandardEvent is really a StandardEvent */
    # Get a sample from the second antecedent of the standard event */
    size = 2000
    # Check if the failure probabilities are the same */
    print("Failure probability (Event)=%.6f" %
          myEvent.getSample(size).computeMean()[0])
    print("Failure probability (StandardEvent)=%.6f" %
          stdEvent.getSample(size).computeMean()[0])

    x = [[1.0, 0.5, 1.0, 0.5], [2.0, 1.0, 2.0, 1.0], [3.0, 1.5, 3.0, 1.5]]
    p = [0.3, 0.325, 0.375]
    myDistribution3 = UserDefined(x, p)

    # We create a 'usual' RandomVector from the Distribution */
    vect3 = RandomVector(myDistribution3)

    # We create a composite random vector */
    output3 = CompositeRandomVector(myFunction, vect3)

    # We try to create a StandardEvent from this RandomVector */
    try:
        myStandardEvent3 = StandardEvent(output3, Less(), 1.0)
    except:
        print("Error trying to build myStandardEvent3")

except:
    import sys
    print("t_StandardEvent_std.py", sys.exc_info()[0], sys.exc_info()[1])
